# fontello font demo

show codes
icon-mail0xe800
icon-star0xe801
icon-star-empty0xe802
icon-star-half0xe803
icon-star-half-alt0xe804
icon-user0xe805
icon-zoom-in0xe806
icon-down-big0xe807
icon-left-big0xe808
icon-up-big0xe809
icon-down-open0xe80a
icon-left-open0xe80b
icon-angle-down0xe80c
icon-angle-circled-left0xe80d
icon-angle-circled-right0xe80e
icon-angle-circled-up0xe80f
icon-angle-circled-down0xe810
icon-th-large0xe811
icon-th0xe812
icon-th-list0xe813
icon-ok0xe814
icon-ok-circled0xe815
icon-ok-circled20xe816
icon-ok-squared0xe817
icon-help-circled0xe818
icon-info-circled0xe819
icon-info0xe81a
icon-home0xe81b
icon-link0xe81c
icon-unlink0xe81d
icon-link-ext0xe81e
icon-flag-empty0xe81f
icon-flag-checkered0xe820
icon-thumbs-up0xe821
icon-thumbs-down0xe822
icon-thumbs-up-alt0xe823
icon-thumbs-down-alt0xe824
icon-download0xe825
icon-edit0xe826
icon-print0xe827
icon-retweet0xe828
icon-keyboard0xe829
icon-gamepad0xe82a
icon-comment0xe82b
icon-chat0xe82c
icon-lock0xe82d
icon-music0xe82e
icon-tint0xe82f
icon-check0xe830
icon-check-empty0xe831
icon-circle0xe832
icon-circle-empty0xe833
icon-asterisk0xe834
icon-gift0xe835
icon-fire0xe836
icon-magnet0xe837
icon-chart-bar0xe838
icon-ticket0xe839
icon-tasks0xe83a
icon-filter0xe83b
icon-beaker0xe83c
icon-magic0xe83d
icon-truck0xe83e
icon-money0xe83f
icon-euro0xe840
icon-pound0xe841
icon-spin10xe842
icon-rupee0xe843
icon-yen0xe844
icon-sort-name-down0xe845
icon-sort-number-up0xe846
icon-sort-number-down0xe847
icon-hammer0xe848
icon-gauge0xe849
icon-sitemap0xe84a
icon-spinner0xe84b
icon-coffee0xe84c
icon-food0xe84d
icon-beer0xe84e
icon-user-md0xe84f
icon-anchor0xe850
icon-terminal0xe851
icon-eraser0xe852
icon-puzzle0xe853
icon-shield0xe854
icon-extinguisher0xe855
icon-bullseye0xe856
icon-adn0xe857
icon-android0xe858
icon-apple0xe859
icon-bitbucket0xe85a
icon-github-squared0xe85b
icon-github-circled0xe85c
icon-lock-open0xe85d
icon-gplus-squared0xe85e
icon-gplus0xe85f
icon-html50xe860
icon-instagramm0xe861
icon-linkedin-squared0xe862
icon-linux0xe863
icon-pinterest-circled0xe864
icon-spin20xe865
icon-twitter0xe866
icon-vkontakte0xe867
icon-brush0xe868
icon-windows0xe869
icon-spin30xe86a
icon-spin40xe86b
icon-youtube0xe86c
icon-share0xe86d
icon-youtube-play0xe86e
icon-spin50xe86f
icon-spin60xe870
icon-ellipsis0xe871
icon-ellipsis-vert0xe872
icon-off0xe873
icon-road0xe874
icon-list-alt0xe875
icon-qrcode0xe876
icon-barcode0xe877
icon-book0xe878
icon-ajust0xe879
icon-credit-card0xe87a
icon-floppy0xe87b
icon-megaphone0xe87c
icon-hdd0xe87d
icon-fork0xe87f
icon-rocket0xe880
icon-bug0xe881
icon-certificate0xe882
icon-renminbi0xe883
icon-won0xe884
icon-bitcoin0xe885
icon-sort0xe886
icon-sort-down0xe887
icon-sort-up0xe888
icon-sort-alt-up0xe889
icon-sort-alt-down0xe88a
icon-sort-name-up0xe88b
icon-stethoscope0xe88c
icon-ambulance0xe88d
icon-medkit0xe88e
icon-h-sigh0xe88f
icon-hospital0xe890
icon-building0xe891
icon-smile0xe892
icon-frown0xe893
icon-meh0xe894
icon-css30xe896
icon-dropbox0xe898
icon-facebook0xe899
icon-facebook-squared0xe89a
icon-flickr0xe89b
icon-github0xe89d
icon-skype0xe8a1
icon-stackoverflow0xe8a2
icon-trello0xe8a3
icon-tumblr0xe8a4
icon-tumblr-squared0xe8a5
icon-twitter-squared0xe8a6
icon-headphones0xe8a7
icon-clock0xe8a8
icon-lightbulb0xe8a9
icon-block0xe8aa
icon-resize-full0xe8ab
icon-resize-full-alt0xe8ac
icon-resize-small0xe8ad
icon-resize-vertical0xe8ae
icon-resize-horizontal0xe8af
icon-zoom-out0xe8b0
icon-down-circled20xe8b1
icon-up-circled20xe8b2
icon-angle-double-left0xe8b3
icon-angle-double-right0xe8b4
icon-angle-double-up0xe8b5
icon-angle-double-down0xe8b6
icon-right-hand0xe8b7
icon-left-hand0xe8b8
icon-up-hand0xe8b9
icon-down-hand0xe8ba
icon-left-circled0xe8bb
icon-right-circled0xe8bc
icon-up-circled0xe8bd
icon-down-circled0xe8be
icon-cw0xe8bf
icon-ccw0xe8c0
icon-arrows-cw0xe8c1
icon-level-up0xe8c2
icon-play0xe8c3
icon-play-circled0xe8c4
icon-play-circled20xe8c5
icon-stop0xe8c6
icon-pause0xe8c7
icon-to-end0xe8c8
icon-to-end-alt0xe8c9
icon-to-start0xe8ca
icon-to-start-alt0xe8cb
icon-fast-fw0xe8cc
icon-fast-bw0xe8cd
icon-eject0xe8ce
icon-target0xe8cf
icon-signal0xe8d0
icon-globe0xe8d1
icon-sun0xe8d2
icon-cloud0xe8d3
icon-flash0xe8d4
icon-moon0xe8d5
icon-umbrella0xe8d6
icon-flight0xe8d7
icon-leaf0xe8d9
icon-font0xe8da
icon-bold0xe8db
icon-italic0xe8dc
icon-text-height0xe8dd
icon-text-width0xe8de
icon-indent-right0xe8df
icon-list-bullet0xe8e0
icon-list-numbered0xe8e1
icon-strike0xe8e2
icon-underline0xe8e3
icon-superscript0xe8e4
icon-subscript0xe8e5
icon-table0xe8e6
icon-columns0xe8e7
icon-crop0xe8e8
icon-scissors0xe8e9
icon-paste0xe8ea
icon-briefcase0xe8eb
icon-suitcase0xe8ec
icon-right-big0xe8ed
icon-right-open0xe8ee
icon-up-open0xe8ef
icon-angle-left0xe8f0
icon-angle-right0xe8f1
icon-angle-up0xe8f2
icon-level-down0xe8f3
icon-shuffle0xe8f4
icon-exchange0xe8f5
icon-collapse0xe8f6
icon-collapse-top0xe8f7
icon-expand0xe8f8
icon-award0xe8f9
icon-desktop0xe8fa
icon-laptop0xe8fb
icon-tablet0xe8fc
icon-mobile0xe8fd
icon-inbox0xe8fe
icon-align-left0xe8ff
icon-align-center0xe900
icon-align-right0xe901
icon-align-justify0xe902
icon-list0xe903
icon-indent-left0xe904
icon-doc-text0xe905
icon-doc-inv0xe906
icon-doc-text-inv0xe907
icon-folder0xe908
icon-logout0xe909
icon-mic0xe90a
icon-mute0xe90b
icon-volume-off0xe90c
icon-down-dir0xe90d
icon-up-dir0xe90e
icon-left-dir0xe90f
icon-right-dir0xe910
icon-down0xe911
icon-left0xe912
icon-right0xe913
icon-up0xe914
icon-folder-open0xe915
icon-folder-empty0xe916
icon-volume-down0xe917
icon-volume-up0xe918
icon-folder-open-empty0xe919
icon-box0xe91a
icon-rss0xe91b
icon-rss-squared0xe91c
icon-phone0xe91d
icon-phone-squared0xe91e
icon-menu0xe91f
icon-cog0xe920
icon-cog-alt0xe921
icon-wrench0xe922
icon-basket0xe923
icon-calendar0xe924
icon-calendar-empty0xe925
icon-login0xe926
icon-move0xe927
icon-users0xe928
icon-male0xe929
icon-female0xe92a
icon-video0xe92b
icon-videocam0xe92c
icon-picture0xe92d
icon-camera0xe92e
icon-camera-alt0xe92f
icon-cancel0xe930
icon-cancel-circled0xe931
icon-cancel-circled20xe932
icon-plus0xe933
icon-plus-circled0xe934
icon-plus-squared0xe935
icon-minus0xe937
icon-minus-circled0xe938
icon-minus-squared0xe939
icon-minus-squared-alt0xe93a
icon-help0xe93c
icon-link-ext-alt0xe93d
icon-attach0xe93e
icon-pin0xe942
icon-eye0xe943
icon-eye-off0xe944
icon-tag0xe945
icon-tags0xe946
icon-bookmark0xe947
icon-bookmark-empty0xe948
icon-flag0xe949
icon-upload0xe94a
icon-download-cloud0xe94b
icon-upload-cloud0xe94c
icon-reply0xe94d
icon-reply-all0xe94e
icon-forward0xe94f
icon-quote-left0xe950
icon-quote-right0xe951
icon-code0xe952
icon-export0xe953
icon-export-alt0xe954
icon-pencil0xe955
icon-pencil-squared0xe956
icon-comment-empty0xe957
icon-chat-empty0xe958
icon-bell0xe959
icon-bell-alt0xe95a
icon-attention-alt0xe95b
icon-attention0xe95c
icon-attention-circled0xe95d
icon-location0xe95e
icon-direction0xe95f
icon-compass0xe960
icon-trash0xe961
icon-doc0xe962
icon-docs0xe963
icon-heart-empty0xe964
icon-heart0xe965
icon-mail-alt0xe966
icon-search0xe967
icon-book-10xe968
icon-book-alt0xe969
icon-chart-pie0xe96a
icon-chart-pie-alt0xe96b
icon-key-10xe96d
icon-key-inv0xe96e
icon-box-10xe96f
icon-layers0xe970
icon-picture-10xe971